@@ -1502,6 +1502,19 @@ class Commands:
             f"fill {translate(corner1)} {translate(corner2)} {translate(block)} {translate(mode) if mode else ''} {translate(replace_block) if replace_block else ''}"
         )
 
+    @staticmethod
+    def function(function: Union["Function", str]) -> str:
+        """
+        function - Executes a function
+
+        Args:
+            function (Union[Function, str]): The function to execute. An alternative to ``function <FunctionObj>`` is just ``<FunctionObj()>``.
+
+        Returns:
+            str: Command
+        """
+        return Commands.push(f"function {translate(function)}")
+    
     @staticmethod
     def gamemode(mode: gamemode, players: Selector) -> str:
         """
